@@ -9,6 +9,8 @@
 #'
 #' @keywords internal
 #'
+#' @author Kaifeng Lu, \email{kaifenglu@@gmail.com}
+#' 
 #' @export
 print.design <- function(x, ...) {
   a = x$overallResults;
@@ -16,36 +18,55 @@ print.design <- function(x, ...) {
   k = a$kMax;
   
   if (k>1) {
-    str1 = paste0("Group-sequential trial with ", k, " stages")
+    str1 = paste0("Group-sequential design with ", k, " stages")
   } else {
     str1 = "Fixed design"
   }
   
-  
   str2 <- paste0("Overall power: ",
                  round(a$overallReject, 3), ", ",
-                 "overall significance level (1-sided): ",
+                 "overall alpha (1-sided): ",
                  round(a$alpha, 4))
   
-  str3 <- paste0("Drift parameter: ", round(a$drift, 3))
-  str4 <- paste0("Inflation factor: ", round(a$inflationFactor, 3))
+  if (x$settings$typeBetaSpending != 'none') {
+      str2 <- paste0(str2, ", ", 
+                     "attained alpha: ", round(a$attainedAlpha, 4))
+  }
   
+  str3 <- paste0("theta: ", round(a$theta, 3), ", ", 
+                 "maximum information: ", round(a$maxInformation, 2))
   
-  df1 = data.frame(x = rep("", 5))
-  colnames(df1) = NULL
-  row.names(df1) = c(str1, str2, str3, str4, "")
+  str4 <- paste0("Drift parameter: ", round(a$drift, 3), ", ", 
+                 "inflation factor: ", round(a$inflationFactor, 3))
+  
+  if (k>1) {
+    str5 <- paste0("Expected information under H1: ", 
+                   round(a$expectedInformationH1, 2), ", ",
+                   "expected information under H0: ", 
+                   round(a$expectedInformationH0, 2))
+    df1 = data.frame(x = rep("", 6))
+    colnames(df1) = NULL
+    rownames(df1) = c(str1, str2, str3, str4, str5, "")
+  } else {
+    df1 = data.frame(x = rep("", 5))
+    colnames(df1) = NULL
+    rownames(df1) = c(str1, str2, str3, str4, "")
+  }
   
   
   if (k>1) {
     b <- s[, c("informationRates", "efficacyBounds", "futilityBounds",
                "cumulativeRejection", "cumulativeFutility",
-               "cumulativeAlphaSpent", 
-               "efficacyP", "futilityP")]
+               "cumulativeAlphaSpent", "efficacyTheta", "futilityTheta", 
+               "efficacyP", "futilityP", "information", 
+               "cumulativeRejectionH0", "cumulativeFutilityH0")]
     
     # format number of digits after decimal for each column
-    j3 <- c(1,2,3,4,5)
-    j4 <- c(6,7,8)
+    j2 <- 11
+    j3 <- c(1,2,3,4,5,7,8,12,13)
+    j4 <- c(6,9,10)
     
+    b[j2] <- lapply(b[j2], formatC, format = "f", digits = 2)
     b[j3] <- lapply(b[j3], formatC, format = "f", digits = 3)
     b[j4] <- lapply(b[j4], formatC, format = "f", digits = 4)
     
@@ -57,26 +78,32 @@ print.design <- function(x, ...) {
                        "Cumulative rejection",
                        "Cumulative futility",
                        "Cumulative alpha spent",
+                       "Efficacy boundary (theta-scale)",
+                       "Futility boundary (theta-scale)",
                        "Efficacy boundary (p-scale)",
-                       "Futility boundary (p-scale)")
+                       "Futility boundary (p-scale)",
+                       "Information", 
+                       "Cumulative rejection under H0",
+                       "Cumulative futility under H0")
       
     } else {
-      df = t(b[,c(1,2,4,6,7)])
+      df = t(b[,c(1,2,4,6,7,9,11)])
       rownames(df) = c("Information rate",
                        "Efficacy boundary (Z-scale)",
                        "Cumulative rejection",
                        "Cumulative alpha spent",
-                       "Efficacy boundary (p-scale)")
+                       "Efficacy boundary (theta-scale)",
+                       "Efficacy boundary (p-scale)",
+                       "Information")
     }
     
-    
     colnames(df) <- paste("Stage", seq_len(ncol(df)), sep=" ")
   } else {
-    b <- s[, c("efficacyBounds", "efficacyP")]
+    b <- s[, c("efficacyBounds", "efficacyTheta", "efficacyP")]
     
     # format number of digits after decimal for each column
-    j3 <- 1
-    j4 <- 2
+    j3 <- c(1,2)
+    j4 <- 3
     
     b[j3] <- lapply(b[j3], formatC, format = "f", digits = 3)
     b[j4] <- lapply(b[j4], formatC, format = "f", digits = 4)      
@@ -84,6 +111,7 @@ print.design <- function(x, ...) {
     df = t(b)
     
     rownames(df) = c("Efficacy boundary (Z-scale)",
+                     "Efficacy boundary (theta-scale)",
                      "Efficacy boundary (p-scale)")
     
     colnames(df) <- NA
@@ -94,6 +122,160 @@ print.design <- function(x, ...) {
   invisible(x)
 }
 
+#' @title Print adaptive group sequential design
+#' @description Prints the primary and second trial information for 
+#' an adaptive group sequential design.
+#'
+#' @param x The adaptDesign object to print.
+#' @param ... Ensures that all arguments starting from "..." are named.
+#'
+#' @return A tabular printout of the design elements.
+#'
+#' @keywords internal
+#'
+#' @author Kaifeng Lu, \email{kaifenglu@@gmail.com}
+#'
+#' @export
+print.adaptDesign <- function(x, ...) {
+  des1 = x$primaryTrial
+  
+  str1 = "Primary trial:"
+  str2 = paste0("Group-sequential design with ", des1$kMax, " stages")
+  str3 = paste0("Interim adaptation look: ",  des1$L, ", ", 
+                "z-statistic value: ", round(des1$zL, 3))
+  str4 = paste0("Muller & Schafer method for secondary trial: ", 
+                des1$MullerSchafer)
+  
+  df1a = data.frame(x = rep("", 5))
+  colnames(df1a) = NULL
+  rownames(df1a) = c(str1, str2, str3, str4, "")
+  
+  b <- data.frame(informationRates = des1$informationRates,
+                  efficacyBounds = des1$efficacyBounds,
+                  futilityBounds = des1$futilityBounds)
+  
+  b[1:3] <- lapply(b[1:3], formatC, format = "f", digits = 3)
+
+  if (!all(des1$futilityBounds[1:(des1$kMax-1)] == -6)) {
+    df1b = t(b)
+    rownames(df1b) = c("Information rate",
+                       "Efficacy boundary (Z-scale)",
+                       "Futility boundary (Z-scale)")
+  } else {
+    df1b = t(b[1:2])
+    rownames(df1b) = c("Information rate",
+                       "Efficacy boundary (Z-scale)")
+  }
+  
+  colnames(df1b) <- paste("Stage", seq_len(ncol(df1b)), sep=" ")
+  
+  
+  des2 = x$secondaryTrial
+  a = des2$overallResults;
+  s = des2$byStageResults;
+  k = a$kMax;
+  
+  str1 = "Secondary trial:"
+  
+  if (k>1) {
+    str2 = paste0("Group-sequential design with ", k, " stages")
+  } else {
+    str2 = "Fixed design"
+  }
+  
+  str3 <- paste0("Overall power: ",
+                 round(a$overallReject, 3), ", ",
+                 "overall significance level (1-sided): ",
+                 round(a$alpha, 4))
+  
+  str4 <- paste0("theta: ", round(a$theta, 3), ", ", 
+                 "maximum information: ", round(a$maxInformation, 2))
+  
+  str5 <- paste0("Drift parameter: ", round(a$drift, 3), ", ", 
+                 "inflation factor: ", round(a$inflationFactor, 3))
+  
+  if (k>1) {
+    str6 <- paste0("Expected information under H1: ", 
+                   round(a$expectedInformationH1, 2), ", ", 
+                   "Expected information under H0: ", 
+                   round(a$expectedInformationH0, 2))
+    df2a = data.frame(x = rep("", 7))
+    colnames(df2a) = NULL
+    rownames(df2a) = c(str1, str2, str3, str4, str5, str6, "")
+  } else {
+    df2a = data.frame(x = rep("", 6))
+    colnames(df2a) = NULL
+    rownames(df2a) = c(str1, str2, str3, str4, str5, "")
+  }
+  
+  
+  if (k>1) {
+    b <- s[, c("informationRates", "efficacyBounds", "futilityBounds",
+               "cumulativeRejection", "cumulativeFutility",
+               "cumulativeAlphaSpent", "efficacyTheta", "futilityTheta", 
+               "efficacyP", "futilityP", "information")]
+    
+    # format number of digits after decimal for each column
+    j2 <- 11
+    j3 <- c(1,2,3,4,5,7,8)
+    j4 <- c(6,9,10)
+    
+    b[j2] <- lapply(b[j2], formatC, format = "f", digits = 2)
+    b[j3] <- lapply(b[j3], formatC, format = "f", digits = 3)
+    b[j4] <- lapply(b[j4], formatC, format = "f", digits = 4)
+    
+    if (des2$settings$typeBetaSpending != 'none') {
+      df2b = t(b)
+      rownames(df2b) = c("Information rate",
+                         "Efficacy boundary (Z-scale)",
+                         "Futility boundary (Z-scale)",
+                         "Cumulative rejection",
+                         "Cumulative futility",
+                         "Cumulative alpha spent",
+                         "Efficacy boundary (theta-scale)",
+                         "Futility boundary (theta-scale)",
+                         "Efficacy boundary (p-scale)",
+                         "Futility boundary (p-scale)",
+                         "Information")
+      
+    } else {
+      df2b = t(b[,c(1,2,4,6,7,9,11)])
+      rownames(df2b) = c("Information rate",
+                         "Efficacy boundary (Z-scale)",
+                         "Cumulative rejection",
+                         "Cumulative alpha spent",
+                         "Efficacy boundary (theta-scale)",
+                         "Efficacy boundary (p-scale)",
+                         "Information")
+    }
+    
+    colnames(df2b) <- paste("Stage", seq_len(ncol(df2b)), sep=" ")
+  } else {
+    b <- s[, c("efficacyBounds", "efficacyTheta", "efficacyP")]
+    
+    # format number of digits after decimal for each column
+    j3 <- c(1,2)
+    j4 <- 3
+    
+    b[j3] <- lapply(b[j3], formatC, format = "f", digits = 3)
+    b[j4] <- lapply(b[j4], formatC, format = "f", digits = 4)      
+    
+    df2b = t(b)
+    
+    rownames(df2a) = c("Efficacy boundary (Z-scale)",
+                       "Efficacy boundary (theta-scale)",
+                       "Efficacy boundary (p-scale)")
+    
+    colnames(df2b) <- NA
+  }
+  
+  print(df1a, ..., na.print = "" , quote = FALSE )
+  print(df1b, ..., na.print = "" , quote = FALSE )
+  print(df2a, ..., na.print = "" , quote = FALSE )
+  print(df2b, ..., na.print = "" , quote = FALSE )
+  invisible(x)
+}
+
 
 #' @title Print power and sample size results
 #' @description Prints the summary statistics from power calculation.
@@ -105,6 +287,8 @@ print.design <- function(x, ...) {
 #'
 #' @keywords internal
 #'
+#' @author Kaifeng Lu, \email{kaifenglu@@gmail.com}
+#'
 #' @export
 print.lrpower <- function(x, ...) {
   a = x$overallResults;
@@ -112,7 +296,7 @@ print.lrpower <- function(x, ...) {
   k = a$kMax;
   
   if (k>1) {
-    str1 = paste0("Group-sequential trial with ", k, " stages")
+    str1 = paste0("Group-sequential design with ", k, " stages")
   } else {
     str1 = "Fixed design"
   }
@@ -171,7 +355,7 @@ print.lrpower <- function(x, ...) {
   
   df1 = data.frame(x = rep("", 8))
   colnames(df1) = NULL
-  row.names(df1) = c(str1, str2, str3, str4, str5, str6, str7, "")
+  rownames(df1) = c(str1, str2, str3, str4, str5, str6, str7, "")
   
   
   if (k>1) {
@@ -339,13 +523,15 @@ print.lrpower <- function(x, ...) {
 #'
 #' @keywords internal
 #'
+#' @author Kaifeng Lu, \email{kaifenglu@@gmail.com}
+#'
 #' @export
 print.lrsim <- function(x, ...) {
   a = x$overview;
   k = a$kMax;
   
   if (k>1) {
-    str1 = paste0("Group-sequential trial with ", k, " stages")
+    str1 = paste0("Group-sequential design with ", k, " stages")
   } else {
     str1 = "Fixed design"
   }
@@ -376,7 +562,7 @@ print.lrsim <- function(x, ...) {
   
   df1 = data.frame(x = rep("", 8))
   colnames(df1) = NULL
-  row.names(df1) = c(str1, str2, str3, str4, str5, str6, str7, "")
+  rownames(df1) = c(str1, str2, str3, str4, str5, str6, str7, "")
   
   
   if (k>1) {
